aboutsummaryrefslogtreecommitdiffstats
path: root/sys/syz-extract
diff options
context:
space:
mode:
authorTobias Klauser <tklauser@distanz.ch>2020-06-25 19:15:57 +0200
committerDmitry Vyukov <dvyukov@google.com>2020-06-26 16:41:30 +0200
commit42306a435d930eba6b8f1c447a2a7ca50410f533 (patch)
tree02a7c3182aec5a475447adf410b122c9af3ecca0 /sys/syz-extract
parentb202c7a8a2a033a10f17bb2fa0f790851075ae2b (diff)
sys/syz-extract: ignore *_kvm.txt on linux/riscv64
The Linux RISC-V port in linux-next doesn't support KVM yet. Ignore it for now until KVM support is added upstream. Signed-off-by: Tobias Klauser <tklauser@distanz.ch>
Diffstat (limited to 'sys/syz-extract')
-rw-r--r--sys/syz-extract/linux.go7
1 files changed, 4 insertions, 3 deletions
diff --git a/sys/syz-extract/linux.go b/sys/syz-extract/linux.go
index ef3a9c6d3..05789ef55 100644
--- a/sys/syz-extract/linux.go
+++ b/sys/syz-extract/linux.go
@@ -134,10 +134,11 @@ func (*linux) prepareArch(arch *Arch) error {
}
func (*linux) processFile(arch *Arch, info *compiler.ConstInfo) (map[string]uint64, map[string]bool, error) {
- if strings.HasSuffix(info.File, "_kvm.txt") && arch.target.Arch == "arm" {
+ if strings.HasSuffix(info.File, "_kvm.txt") && (arch.target.Arch == "arm" || arch.target.Arch == "riscv64") {
// Hack: KVM is not supported on ARM anymore. We may want some more official support
// for marking descriptions arch-specific, but so far this combination is the only one.
// Note: syz-sysgen also ignores this file for arm.
return nil, nil, nil
}
headerArch := arch.target.KernelHeaderArch
@@ -134,10 +134,11 @@ func (*linux) prepareArch(arch *Arch) error {
// Hack: KVM is not supported on ARM anymore. We may want some more official support
- // for marking descriptions arch-specific, but so far this combination is the only one.
- // Note: syz-sysgen also ignores this file for arm.
+ // for marking descriptions arch-specific, but so far this combination is the only
+ // one. For riscv64, KVM is not supported yet but might be in the future.
+ // Note: syz-sysgen also ignores this file for arm and riscv64.
return nil, nil, nil
}